@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::Author::ZOFFIX;
 
-our $VERSION = '1.001006'; # VERSION
+our $VERSION = '1.001007'; # VERSION
 
 use Moose;
 with (
@@ -44,7 +44,6 @@ sub configure {
         Prereqs::AuthorDeps
         MinimumPerl
         MetaProvides::Package
-        GithubMeta
         InstallGuide/,
         [
             ReadmeAnyFromPod => {
@@ -85,6 +84,7 @@ sub configure {
         [
             AutoMetaResources => {
                 'bugtracker.github' => 'user:zoffixznet',
+                'bugtracker.mailto' => 'cpan@zoffix.com',
                 'repository.github' => 'user:zoffixznet',
                 homepage => 'http://metacpan.org/release/%{dist}',
             },
